@@ -11,7 +11,7 @@ use Coro::Channel;
 use Coro::ProcessPool::Process;
 use Coro::ProcessPool::Util qw(cpu_count);
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 if ($^O eq 'MSWin32') {
     die 'MSWin32 is not supported';
@@ -28,6 +28,11 @@ sub new {
     }, $class;
 }
 
+sub DESTROY {
+  my $self = shift;
+  $self->shutdown;
+}
+
 sub shutdown {
     my $self = shift;
     for (1 .. $self->{num_procs}) {
