@@ -31,10 +31,17 @@ sub new {
 }
 
 sub DESTROY {
-    if ($_[0] && $_[0]->{pid}) {
-        $_[0]->terminate(1);
-        $_[0]->cleanup;
-    }
+    my $self = shift;
+    $self->terminate;
+
+#    if ($_[0] && $_[0]->{pid}) {
+#        my $pid = $_[0]->{pid};
+#        while ($pid > 0) {
+#            $pid = waitpid($pid, WNOHANG);
+#            Coro::AnyEvent::sleep(0.1)
+#                if $pid > 0;
+#        }
+#    }
 }
 
 #-------------------------------------------------------------------------------
@@ -76,7 +83,7 @@ sub spawn {
 
     $self->{child_err_mon} = async {
         while (my $line = $self->{child_err}->readline) {
-            warn "(WORKER) $line";
+            warn "(WORKER PID $self->{pid}) $line";
         }
     };
 
@@ -91,28 +98,17 @@ sub is_running {
 }
 
 sub terminate {
-    my ($self, $block) = @_;
-    my $pid = $self->{pid};
+    my $self = shift;
 
     if ($self->is_running) {
-        $self->{child_err}->close;
-
-        $self->{child_err_mon}->safe_cancel;
+        my $pid = $self->{pid};
+        $self->{mailbox}->shutdown;
         $self->{child_err_mon}->join;
 
-        if (kill(0, $pid)) {
-            warn("Error killing pid %d: %s", $pid, $!)
-                unless kill(9, $pid) || $!{ESRCH};
-        }
-
-        if ($block) {
-            waitpid($pid, 0);
-        } else {
-            while ($pid > 0) {
-                $pid = waitpid($pid, WNOHANG);
-                Coro::AnyEvent::sleep(0.1)
-                    if $pid > 0;
-            }
+        while ($pid > 0) {
+            $pid = waitpid($pid, WNOHANG);
+            Coro::AnyEvent::sleep(0.1)
+              if $pid > 0;
         }
     }
 
@@ -132,7 +128,6 @@ sub send {
 
 sub recv {
     my ($self, $msgid) = @_;
-    croak 'not running' unless $self->is_running;
     my $data = $self->{mailbox}->recv($msgid);
     ++$self->{processed};
 
